[Scummvm-cvs-logs] scummvm master -> 03b8800080bcf348c938ff3db0e7545798568973

lordhoto lordhoto at gmail.com
Wed Sep 3 00:02:32 CEST 2014


This automated email contains information about 3 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
9d885bce22 GUI: s/savegame/saved game/
cf8e28c40c CLI: change "savegames" into "saved games", same as in GUI
03b8800080 Merge pull request #492 from BenCastricum/misc


Commit: 9d885bce2249e2dd75521cb3c68513dcc4dbc34a
    https://github.com/scummvm/scummvm/commit/9d885bce2249e2dd75521cb3c68513dcc4dbc34a
Author: Ben Castricum (github at bencastricum.nl)
Date: 2014-08-22T07:11:03+02:00

Commit Message:
GUI: s/savegame/saved game/

Makes it consistant throughout the GUI

Changed paths:
    gui/launcher.cpp
    gui/options.cpp
    gui/saveload-dialog.cpp
    po/be_BY.po
    po/ca_ES.po
    po/cs_CZ.po
    po/da_DA.po
    po/de_DE.po
    po/es_ES.po
    po/eu.po
    po/fi_FI.po
    po/fr_FR.po
    po/gl_ES.po
    po/hu_HU.po
    po/it_IT.po
    po/nb_NO.po
    po/nn_NO.po
    po/pl_PL.po
    po/pt_BR.po
    po/ru_RU.po
    po/se_SE.po
    po/uk_UA.po



diff --git a/gui/launcher.cpp b/gui/launcher.cpp
index 9ac97a7..5d7080a 100644
--- a/gui/launcher.cpp
+++ b/gui/launcher.cpp
@@ -194,10 +194,10 @@ EditGameDialog::EditGameDialog(const String &domain, const String &desc)
 
 	// GUI:  Label & edit widget for the game ID
 	if (g_system->getOverlayWidth() > 320)
-		new StaticTextWidget(tab, "GameOptions_Game.Id", _("ID:"), _("Short game identifier used for referring to savegames and running the game from the command line"));
+		new StaticTextWidget(tab, "GameOptions_Game.Id", _("ID:"), _("Short game identifier used for referring to saved games and running the game from the command line"));
 	else
-		new StaticTextWidget(tab, "GameOptions_Game.Id", _c("ID:", "lowres"), _("Short game identifier used for referring to savegames and running the game from the command line"));
-	_domainWidget = new DomainEditTextWidget(tab, "GameOptions_Game.Domain", _domain, _("Short game identifier used for referring to savegames and running the game from the command line"));
+		new StaticTextWidget(tab, "GameOptions_Game.Id", _c("ID:", "lowres"), _("Short game identifier used for referring to saved games and running the game from the command line"));
+	_domainWidget = new DomainEditTextWidget(tab, "GameOptions_Game.Domain", _domain, _("Short game identifier used for referring to saved games and running the game from the command line"));
 
 	// GUI:  Label & edit widget for the description
 	if (g_system->getOverlayWidth() > 320)
@@ -336,10 +336,10 @@ EditGameDialog::EditGameDialog(const String &domain, const String &desc)
 
 	// GUI:  Button + Label for the save path
 	if (g_system->getOverlayWidth() > 320)
-		new ButtonWidget(tab, "GameOptions_Paths.Savepath", _("Save Path:"), _("Specifies where your savegames are put"), kCmdSaveBrowser);
+		new ButtonWidget(tab, "GameOptions_Paths.Savepath", _("Save Path:"), _("Specifies where your saved games are put"), kCmdSaveBrowser);
 	else
-		new ButtonWidget(tab, "GameOptions_Paths.Savepath", _c("Save Path:", "lowres"), _("Specifies where your savegames are put"), kCmdSaveBrowser);
-	_savePathWidget = new StaticTextWidget(tab, "GameOptions_Paths.SavepathText", savePath, _("Specifies where your savegames are put"));
+		new ButtonWidget(tab, "GameOptions_Paths.Savepath", _c("Save Path:", "lowres"), _("Specifies where your saved games are put"), kCmdSaveBrowser);
+	_savePathWidget = new StaticTextWidget(tab, "GameOptions_Paths.SavepathText", savePath, _("Specifies where your saved games are put"));
 
 	_savePathClearButton = addClearButton(tab, "GameOptions_Paths.SavePathClearButton", kCmdSavePathClear);
 
@@ -630,7 +630,7 @@ LauncherDialog::LauncherDialog()
 		new ButtonWidget(this, "Launcher.StartButton", _("~S~tart"), _("Start selected game"), kStartCmd);
 
 	_loadButton =
-		new ButtonWidget(this, "Launcher.LoadGameButton", _("~L~oad..."), _("Load savegame for selected game"), kLoadGameCmd);
+		new ButtonWidget(this, "Launcher.LoadGameButton", _("~L~oad..."), _("Load saved game for selected game"), kLoadGameCmd);
 
 	// Above the lowest button rows: two more buttons (directly below the list box)
 	if (g_system->getOverlayWidth() > 320) {
@@ -996,7 +996,7 @@ void LauncherDialog::loadGameButtonPressed(int item) {
 #ifdef ENABLE_EVENTRECORDER
 void LauncherDialog::recordGame(int item) {
 	RecorderDialog recorderDialog;
-	MessageDialog alert(_("Do you want to load savegame?"),
+	MessageDialog alert(_("Do you want to load saved game?"),
 		_("Yes"), _("No"));
 	switch(recorderDialog.runModal(_domains[item])) {
 	case RecorderDialog::kRecordDialogClose:
diff --git a/gui/options.cpp b/gui/options.cpp
index ae7add1..726b89d 100644
--- a/gui/options.cpp
+++ b/gui/options.cpp
@@ -1131,10 +1131,10 @@ GlobalOptionsDialog::GlobalOptionsDialog()
 
 	// Save game path
 	if (g_system->getOverlayWidth() > 320)
-		new ButtonWidget(tab, "GlobalOptions_Paths.SaveButton", _("Save Path:"), _("Specifies where your savegames are put"), kChooseSaveDirCmd);
+		new ButtonWidget(tab, "GlobalOptions_Paths.SaveButton", _("Save Path:"), _("Specifies where your saved games are put"), kChooseSaveDirCmd);
 	else
-		new ButtonWidget(tab, "GlobalOptions_Paths.SaveButton", _c("Save Path:", "lowres"), _("Specifies where your savegames are put"), kChooseSaveDirCmd);
-	_savePath = new StaticTextWidget(tab, "GlobalOptions_Paths.SavePath", "/foo/bar", _("Specifies where your savegames are put"));
+		new ButtonWidget(tab, "GlobalOptions_Paths.SaveButton", _c("Save Path:", "lowres"), _("Specifies where your saved games are put"), kChooseSaveDirCmd);
+	_savePath = new StaticTextWidget(tab, "GlobalOptions_Paths.SavePath", "/foo/bar", _("Specifies where your saved games are put"));
 
 	_savePathClearButton = addClearButton(tab, "GlobalOptions_Paths.SavePathClearButton", kSavePathClearCmd);
 
@@ -1376,7 +1376,7 @@ void GlobalOptionsDialog::close() {
 void GlobalOptionsDialog::handleCommand(CommandSender *sender, uint32 cmd, uint32 data) {
 	switch (cmd) {
 	case kChooseSaveDirCmd: {
-		BrowserDialog browser(_("Select directory for savegames"), true);
+		BrowserDialog browser(_("Select directory for saved games"), true);
 		if (browser.runModal() > 0) {
 			// User made his choice...
 			Common::FSNode dir(browser.getResult());
diff --git a/po/be_BY.po b/po/be_BY.po
index 8419364..9580ff7 100644
--- a/po/be_BY.po
+++ b/po/be_BY.po
@@ -151,7 +151,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "ºÐàÞâÚö öÔíÝâëäöÚÐâÐà, ÒëÚÐàëáâÞþÒÐÝë ÔÛï öÜñÝÐþ ×ÐåÐÒÐÝÝïþ ÓãÛìÝïþ ö ÔÛï "
@@ -321,7 +321,7 @@ msgstr "
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "¿ÐÚÐ×ÒÐÕ èÛïå ÔÐ ×ÐåÐÒÐÝÝïþ ÓãÛìÝö"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -402,7 +402,7 @@ msgid "~L~oad..."
 msgstr "~·~ÐÓàã×öæì..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "·ÐÓàã×öæì ×ÐåÐÒÐÝÝÕ ÔÛï ÐÑàÐÝÐÙ ÓãÛìÝö"
 
 #: gui/launcher.cpp:638
@@ -510,7 +510,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "²ë áÐßàÐþÔë ÖÐÔÐÕæÕ ÒëÔÐÛöæì ÝÐÛÐÔë ÔÛï ÓíâÐÙ ÓãÛìÝö?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "²ë ÖÐÔÐÕæÕ ×ÐÓàã×öæì ÓãÛìÝî?"
 
 #: gui/launcher.cpp:1048
@@ -916,7 +916,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "²ë ßÐÒöÝÝë ßÕàÐ×Ðßãáæöæì ScummVM, ÚÐÑ ãÖëæì ×ÜÕÝë."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "°ÑïàëæÕ ÔëàíÚâÞàëî ÔÛï ×ÐåÐÒÐÝÝïþ"
 
 #: gui/options.cpp:1386
@@ -968,7 +968,7 @@ msgid "Delete"
 msgstr "²ëÔÐÛöæì"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "²ë áÐßàÐþÔë ÖÐÔÐÕæÕ ÒëÔÐÛöæì ÓíâÐ ×ÐåÐÒÐÝÝÕ?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/ca_ES.po b/po/ca_ES.po
index 4f03b75..f12f8f2 100644
--- a/po/ca_ES.po
+++ b/po/ca_ES.po
@@ -148,7 +148,7 @@ msgstr "Identificador:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Identificador de joc curt utilitzat per referir-se a les partides i per "
@@ -318,7 +318,7 @@ msgstr "Cam
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Especifica on es desaran les partides"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -400,7 +400,7 @@ msgid "~L~oad..."
 msgstr "~C~arrega..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Carrega una partida pel joc seleccionat"
 
 #: gui/launcher.cpp:638
@@ -511,7 +511,7 @@ msgstr "Realment voleu suprimir la configuraci
 
 #: gui/launcher.cpp:999
 #, fuzzy
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Voleu carregar o desar el joc?"
 
 #: gui/launcher.cpp:1048
@@ -917,7 +917,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Heu de reiniciar ScummVM perquè tots els canvis tinguin efecte."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Seleccioneu el directori de les partides desades"
 
 #: gui/options.cpp:1386
@@ -971,7 +971,7 @@ msgid "Delete"
 msgstr "Suprimeix"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Realment voleu suprimir aquesta partida?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/cs_CZ.po b/po/cs_CZ.po
index e338206..b6624b1 100644
--- a/po/cs_CZ.po
+++ b/po/cs_CZ.po
@@ -152,7 +152,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Krátký identifikátor her, pou¾ívaný jako odkaz k ulo¾eným hrám a spu¹tìní "
@@ -320,7 +320,7 @@ msgstr "Cesta pro ulo
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Stanovuje, kam jsou umístìny va¹e ulo¾ené hry"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -401,7 +401,7 @@ msgid "~L~oad..."
 msgstr "~N~ahrát..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Nahrát ulo¾enou pozici pro zvolenou hru"
 
 #: gui/launcher.cpp:638
@@ -509,7 +509,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Opravdu chcete odstranit nastavení této hry?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Chcete naèíst ulo¾enou pozici?"
 
 #: gui/launcher.cpp:1048
@@ -911,7 +911,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Pro pou¾ití tìchto nastavení musíte restartovat ScummVM."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Vybrat adresáø pro ulo¾ené hry"
 
 #: gui/options.cpp:1386
@@ -963,7 +963,7 @@ msgid "Delete"
 msgstr "Smazat"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Opravdu chcete tuto ulo¾enou hru vymazat"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/da_DA.po b/po/da_DA.po
index 38457ae..02a8208 100644
--- a/po/da_DA.po
+++ b/po/da_DA.po
@@ -150,7 +150,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Kort spil identifikator til brug for gemmer, og for at køre spillet fra "
@@ -320,7 +320,7 @@ msgstr "Gemme sti:"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Angiver hvor dine gemmer bliver lagt"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -401,7 +401,7 @@ msgid "~L~oad..."
 msgstr "Ind~l~æs..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Indlæs gemmer for det valgte spil"
 
 #: gui/launcher.cpp:638
@@ -509,7 +509,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Vil du virkelig fjerne denne spil konfiguration?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Vil du indlæse gemmer?"
 
 #: gui/launcher.cpp:1048
@@ -910,7 +910,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Du skal genstarte ScummVM før dine ændringer har effekt."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Vælg bibliotek til gemmer"
 
 #: gui/options.cpp:1386
@@ -962,7 +962,7 @@ msgid "Delete"
 msgstr "Slet"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Vil du virkelig slette denne gemmer?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/de_DE.po b/po/de_DE.po
index 99ecc26..fd6ade1 100644
--- a/po/de_DE.po
+++ b/po/de_DE.po
@@ -149,7 +149,7 @@ msgstr "Kennung:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Kurzer Spielname, um die Spielstände zuzuordnen und das Spiel von der "
@@ -319,7 +319,7 @@ msgstr "Spielst
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Legt fest, wo die Spielstände abgelegt werden."
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -400,7 +400,7 @@ msgid "~L~oad..."
 msgstr "~L~aden..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Spielstand für ausgewähltes Spiel laden"
 
 #: gui/launcher.cpp:638
@@ -510,7 +510,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Möchten Sie wirklich diese Spielkonfiguration entfernen?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Möchten Sie einen Spielstand laden?"
 
 #: gui/launcher.cpp:1048
@@ -920,7 +920,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Sie müssen ScummVM neu starten, damit die Änderungen wirksam werden."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Verzeichnis für Spielstände auswählen"
 
 #: gui/options.cpp:1386
@@ -976,7 +976,7 @@ msgid "Delete"
 msgstr "Löschen"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Diesen Spielstand wirklich löschen?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/es_ES.po b/po/es_ES.po
index 23cfa08..13f4099 100644
--- a/po/es_ES.po
+++ b/po/es_ES.po
@@ -149,7 +149,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Identificador usado para las partidas guardadas y para ejecutar el juego "
@@ -319,7 +319,7 @@ msgstr "Partidas:"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Especifica dónde guardar tus partidas"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -400,7 +400,7 @@ msgid "~L~oad..."
 msgstr "~C~argar..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Cargar partida del juego seleccionado"
 
 #: gui/launcher.cpp:638
@@ -508,7 +508,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "¿Seguro que quieres eliminar la configuración de este juego?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "¿Quieres cargar la partida guardada?"
 
 #: gui/launcher.cpp:1048
@@ -916,7 +916,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Tienes que reiniciar ScummVM para aplicar los cambios."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Selecciona el directorio de guardado"
 
 #: gui/options.cpp:1386
@@ -969,7 +969,7 @@ msgid "Delete"
 msgstr "Borrar"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "¿Seguro que quieres borrar esta partida?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/eu.po b/po/eu.po
index 35a36e8..296a854 100644
--- a/po/eu.po
+++ b/po/eu.po
@@ -149,7 +149,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Partida gordeak identifikatzeko eta jokoa komando lerrotik abiarazteko "
@@ -319,7 +319,7 @@ msgstr "Partida gordeak:"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Zure gordetako partidak non gordeko diren zehazten du"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -400,7 +400,7 @@ msgid "~L~oad..."
 msgstr "~K~argatu"
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Aukeraturiko jokorako partida gordea kargatu"
 
 #: gui/launcher.cpp:638
@@ -509,7 +509,7 @@ msgstr "Benetan ezabatu nahi duzu joko-konfigurazio hau?"
 
 #: gui/launcher.cpp:999
 #, fuzzy
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Jokoa kargatu edo gorde nahi duzu?"
 
 #: gui/launcher.cpp:1048
@@ -917,7 +917,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "ScummVM berrabiarazi behar duzu aldaketak indarrean jartzeko"
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Gordetako partiden direktorioa aukeratu"
 
 #: gui/options.cpp:1386
@@ -969,7 +969,7 @@ msgid "Delete"
 msgstr "Ezabatu"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Ezabatu partida gorde hau?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/fi_FI.po b/po/fi_FI.po
index d5182dd..e18c8b9 100644
--- a/po/fi_FI.po
+++ b/po/fi_FI.po
@@ -150,7 +150,7 @@ msgstr "Tunniste:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Lyhyt pelitunniste, jota käytetään kun viitataan pelitallennuksiin ja kun "
@@ -320,7 +320,7 @@ msgstr "Tallennuskansio:"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Määrittää polun pelitallennuksille"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -401,7 +401,7 @@ msgid "~L~oad..."
 msgstr "~L~ataa..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Lataa pelitallennus valitulle pelille"
 
 #: gui/launcher.cpp:638
@@ -510,7 +510,7 @@ msgstr "Haluatko varmasti poistaa pelin asetuksineen listalta?"
 
 #: gui/launcher.cpp:999
 #, fuzzy
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Haluatko tallentaa vai ladata pelin?"
 
 #: gui/launcher.cpp:1048
@@ -918,7 +918,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "ScummVM pitää käynnistää uudelleen jotta muutokset tulevat voimaan."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Valitse hakemisto pelitallennuksille."
 
 #: gui/options.cpp:1386
@@ -970,7 +970,7 @@ msgid "Delete"
 msgstr "Poista"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Haluatko varmasti poistaa tämän pelitallennuksen?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/fr_FR.po b/po/fr_FR.po
index d093699..1a73120 100644
--- a/po/fr_FR.po
+++ b/po/fr_FR.po
@@ -150,7 +150,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "ID compact du jeu utilisée pour identifier les sauvegardes et démarrer le "
@@ -320,7 +320,7 @@ msgstr "Sauvegardes:"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Définie l'emplacement où les fichiers de sauvegarde sont créés"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -401,7 +401,7 @@ msgid "~L~oad..."
 msgstr "~C~harger"
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Charge une sauvegarde pour le jeu sélectionné"
 
 #: gui/launcher.cpp:638
@@ -510,7 +510,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Voulez-vous vraiment supprimer ce jeu ?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Voulez-vous charger le jeu ?"
 
 #: gui/launcher.cpp:1048
@@ -921,7 +921,7 @@ msgstr ""
 "Vous devez relancer ScummVM pour que le changement soit pris en compte."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Sélectionner le répertoire pour les sauvegardes"
 
 #: gui/options.cpp:1386
@@ -975,7 +975,7 @@ msgid "Delete"
 msgstr "Supprimer"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Voulez-vous vraiment supprimer cette sauvegarde ?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/gl_ES.po b/po/gl_ES.po
index 6529d55..0e8f7eb 100644
--- a/po/gl_ES.po
+++ b/po/gl_ES.po
@@ -149,7 +149,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Identificador curto do xogo para os ficheiros de gardado e a execución do "
@@ -317,7 +317,7 @@ msgstr "Cami
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Especifica o lugar dos ficheiros de gardado"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -398,7 +398,7 @@ msgid "~L~oad..."
 msgstr "~C~argar..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Cargar partida do xogo seleccionado"
 
 #: gui/launcher.cpp:638
@@ -506,7 +506,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Seguro que queres eliminar esta configuración de xogo?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Queres cargar a partida gardada?"
 
 #: gui/launcher.cpp:1048
@@ -910,7 +910,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Debes reiniciar ScummVM para que os cambios teñan efecto."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Seleccionar directorio para ficheiros de gardado"
 
 #: gui/options.cpp:1386
@@ -962,7 +962,7 @@ msgid "Delete"
 msgstr "Eliminar"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Seguro que queres eliminar esta partida?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/hu_HU.po b/po/hu_HU.po
index 99e9f9c..cb695e5 100644
--- a/po/hu_HU.po
+++ b/po/hu_HU.po
@@ -151,7 +151,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Rövid játékazonosító a játékmentésekhez és a játék parancssori futtatásához"
@@ -319,7 +319,7 @@ msgstr "Ment
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Játékmentések helyének meghatározása"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -400,7 +400,7 @@ msgid "~L~oad..."
 msgstr "Betöltés"
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Kimentett játékállás betöltése"
 
 #: gui/launcher.cpp:638
@@ -508,7 +508,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Biztosan törölni akarod ezt a játékkonfigurációt?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Akarod hogy betöltésem a játékállást?"
 
 #: gui/launcher.cpp:1048
@@ -909,7 +909,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Indítsd újra a ScummVM-et a változások érvényesítéséhez."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Válassz játékmentés mappát"
 
 #: gui/options.cpp:1386
@@ -961,7 +961,7 @@ msgid "Delete"
 msgstr "Töröl"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Biztos hogy törölni akarod ezt a játékállást?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/it_IT.po b/po/it_IT.po
index d408dbe..e489308 100644
--- a/po/it_IT.po
+++ b/po/it_IT.po
@@ -148,7 +148,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Breve identificatore di gioco utilizzato per il riferimento a salvataggi e "
@@ -317,7 +317,7 @@ msgstr "Salvataggi:"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Specifica dove archiviare i salvataggi"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -398,7 +398,7 @@ msgid "~L~oad..."
 msgstr "~C~arica..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Carica un salvataggio del gioco selezionato"
 
 #: gui/launcher.cpp:638
@@ -506,7 +506,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Sei sicuro di voler rimuovere questa configurazione di gioco?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Vuoi caricare il salvataggio?"
 
 #: gui/launcher.cpp:1048
@@ -914,7 +914,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Devi riavviare ScummVM affinché le modifiche abbiano effetto."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Seleziona la cartella per i salvataggi"
 
 #: gui/options.cpp:1386
@@ -966,7 +966,7 @@ msgid "Delete"
 msgstr "Elimina"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Sei sicuro di voler eliminare questo salvataggio?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/nb_NO.po b/po/nb_NO.po
index 68a39fa..7f7823a 100644
--- a/po/nb_NO.po
+++ b/po/nb_NO.po
@@ -151,7 +151,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Kort spill-identifikator, brukt for å referere til lagrede spill, og å kjøre "
@@ -321,7 +321,7 @@ msgstr "Lagringssti:"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Bestemmer sti til lagrede spill"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -402,7 +402,7 @@ msgid "~L~oad..."
 msgstr "~Å~pne..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Åpne lagret spill for det valgte spillet"
 
 #: gui/launcher.cpp:638
@@ -510,7 +510,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Vil du virkelig fjerne denne spillkonfigurasjonen?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Vil du laste et lagret spill?"
 
 #: gui/launcher.cpp:1048
@@ -911,7 +911,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Du må starte ScummVM på nytt for at endringene skal tre i kraft. "
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Velg mappe for lagrede spill"
 
 #: gui/options.cpp:1386
@@ -963,7 +963,7 @@ msgid "Delete"
 msgstr "Slett"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Vil du virkelig slette dette lagrede spillet?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/nn_NO.po b/po/nn_NO.po
index b05b441..fdf743a 100644
--- a/po/nn_NO.po
+++ b/po/nn_NO.po
@@ -151,7 +151,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Kort spelidentifikator nytta for å referere til lagra spel, og å køyre "
@@ -321,7 +321,7 @@ msgstr "Lagringssti:"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr ""
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -403,7 +403,7 @@ msgid "~L~oad..."
 msgstr "~Å~pne..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Åpne eit lagra spel for the velde spelet"
 
 #: gui/launcher.cpp:638
@@ -509,7 +509,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Vil du verkeleg fjerne denne spelkonfigurasjonen?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Vil du laste det lagra spelet?"
 
 #: gui/launcher.cpp:1048
@@ -910,7 +910,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Du må starte ScummVM på nytt for at endringane skal tre i kraft."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Vel mappe for lagra spel"
 
 #: gui/options.cpp:1386
@@ -962,7 +962,7 @@ msgid "Delete"
 msgstr "Slett"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Vil du verkeleg slette det lagra spelet?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/pl_PL.po b/po/pl_PL.po
index c9085df..5ed85d0 100644
--- a/po/pl_PL.po
+++ b/po/pl_PL.po
@@ -152,7 +152,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Krótki identyfikator gry u¿ywany do rozpoznawania zapisów i uruchamiania gry "
@@ -320,7 +320,7 @@ msgstr "
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Okre¶la gdzie zapisywaæ stan gry"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -401,7 +401,7 @@ msgid "~L~oad..."
 msgstr "~W~czytaj..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Wczytaj zapis wybranej gry"
 
 #: gui/launcher.cpp:638
@@ -508,7 +508,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Na pewno chcesz usun±æ tê grê z konfiguracji?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Chcesz wczytaæ zapis stanu gry?"
 
 #: gui/launcher.cpp:1048
@@ -911,7 +911,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Musisz zrestartowaæ ScummVM, by zmiany zosta³y uwzglêdnione."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Wybierz katalog zapisów"
 
 #: gui/options.cpp:1386
@@ -963,7 +963,7 @@ msgid "Delete"
 msgstr "Skasuj"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Na pewno chcesz skasowaæ ten zapis?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/pt_BR.po b/po/pt_BR.po
index 76d8837..ce60da8 100644
--- a/po/pt_BR.po
+++ b/po/pt_BR.po
@@ -154,7 +154,7 @@ msgstr "C
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Código identificador usado para se referir a jogos salvos e execução do jogo "
@@ -323,7 +323,7 @@ msgstr "Pasta para Salvar"
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Especifique onde guardar seus jogos salvos"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -404,7 +404,7 @@ msgid "~L~oad..."
 msgstr "~C~arregar"
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Carregar jogo salvo do jogo selecionado"
 
 #: gui/launcher.cpp:638
@@ -514,7 +514,7 @@ msgstr "Voc
 
 #: gui/launcher.cpp:999
 #, fuzzy
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Você deseja carregar ou salvar o jogo?"
 
 #: gui/launcher.cpp:1048
@@ -923,7 +923,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Você tem que reiniciar o ScummVM para funcionar."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Selecione a pasta para o jogos salvos"
 
 #: gui/options.cpp:1386
@@ -975,7 +975,7 @@ msgid "Delete"
 msgstr "Excluir"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Você realmente quer excluir este jogo salvo?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/ru_RU.po b/po/ru_RU.po
index b98acd4..f3abf1e 100644
--- a/po/ru_RU.po
+++ b/po/ru_RU.po
@@ -151,7 +151,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "ºÞàÞâÚØÙ ØÔÕÝâØäØÚÐâÞà, ØáßÞÛì×ãÕÜëÙ ÔÛï ØÜñÝ áÞåàÐÝÕÝØÙ ØÓà Ø ÔÛï ×ÐßãáÚÐ "
@@ -320,7 +320,7 @@ msgstr "
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "ÃÚÐ×ëÒÐÕâ ßãâì Ú áÞåàÐÝÕÝØïÜ ØÓàë"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -401,7 +401,7 @@ msgid "~L~oad..."
 msgstr "~·~ÐÓàã×Øâì..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "·ÐÓàã×Øâì áÞåàÝÕÝØÕ ÔÛï ÒëÑàÐÝÝÞÙ ØÓàë"
 
 #: gui/launcher.cpp:638
@@ -509,7 +509,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "²ë ÔÕÙáâÒØâÕÛìÝÞ åÞâØâÕ ãÔÐÛØâì ÝÐáâàÞÙÚØ ÔÛï íâÞÙ ØÓàë?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "²ë åÞâØâÕ ×ÐÓàã×Øâì ØÓàã?"
 
 #: gui/launcher.cpp:1048
@@ -916,7 +916,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "²ë ÔÞÛÖÝë ßÕàÕ×ÐßãáâØâì ScummVM, çâÞÑë ßàØÜÕÝØâì Ø×ÜÕÝÕÝØï."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "²ëÑÕàØâÕ ÔØàÕÚâÞàØî ÔÛï áÞåàÐÝÕÝØÙ"
 
 #: gui/options.cpp:1386
@@ -968,7 +968,7 @@ msgid "Delete"
 msgstr "ÃÔÐÛØâì"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "²ë ÔÕÙáâÒØâÕÛìÝÞ åÞâØâÕ ãÔÐÛØâì íâÞ áÞåàÐÝÕÝØÕ?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/se_SE.po b/po/se_SE.po
index bca8065..7f58403 100644
--- a/po/se_SE.po
+++ b/po/se_SE.po
@@ -151,7 +151,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "Kortnamn för spel. Används för att hänvisa till spardata och att starta "
@@ -321,7 +321,7 @@ msgstr "S
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "Bestämmer var dina spardata lagras"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -402,7 +402,7 @@ msgid "~L~oad..."
 msgstr "~L~adda..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "Ladda spardata för det valda spelet"
 
 #: gui/launcher.cpp:638
@@ -510,7 +510,7 @@ msgid "Do you really want to remove this game configuration?"
 msgstr "Vill du verkligen radera den här spelkonfigurationen?"
 
 #: gui/launcher.cpp:999
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "Vill du ladda sparat spel?"
 
 #: gui/launcher.cpp:1048
@@ -913,7 +913,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "Du måste starta om ScummVM för att ändringarna ska få effekt."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "Välj katalog för spardata"
 
 #: gui/options.cpp:1386
@@ -966,7 +966,7 @@ msgid "Delete"
 msgstr "Radera"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "Vill du verkligen radera den här spardatan?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875
diff --git a/po/uk_UA.po b/po/uk_UA.po
index feb852a..6e1f218 100644
--- a/po/uk_UA.po
+++ b/po/uk_UA.po
@@ -151,7 +151,7 @@ msgstr "ID:"
 
 #: gui/launcher.cpp:197 gui/launcher.cpp:199 gui/launcher.cpp:200
 msgid ""
-"Short game identifier used for referring to savegames and running the game "
+"Short game identifier used for referring to saved games and running the game "
 "from the command line"
 msgstr ""
 "ºÞàÞâÚØÙ öÔÕÝâØäöÚÐâÞà, ïÚØÙ ÒØÚÞàØáâÞÒãôâìáï ÔÛï ÝÐ×Ò ×ÑÕàÕÖÕÝØå öÓÞà ö ÔÛï "
@@ -321,7 +321,7 @@ msgstr "
 
 #: gui/launcher.cpp:339 gui/launcher.cpp:341 gui/launcher.cpp:342
 #: gui/options.cpp:1134 gui/options.cpp:1136 gui/options.cpp:1137
-msgid "Specifies where your savegames are put"
+msgid "Specifies where your saved games are put"
 msgstr "²ÚÐ×ãô èÛïå ÔÞ ×ÑÕàÕÖÕÝì ÓàØ"
 
 #: gui/launcher.cpp:341 gui/options.cpp:1136
@@ -402,7 +402,7 @@ msgid "~L~oad..."
 msgstr "~·~ÐÒÐÝâÐÖØâØ..."
 
 #: gui/launcher.cpp:633
-msgid "Load savegame for selected game"
+msgid "Load saved game for selected game"
 msgstr "·ÐÒÐÝâÐÖØâØ ×ÑÕàÕÖÕÝÝï ÔÛï ÒØÑàÐÝÞ÷ ÓàØ"
 
 #: gui/launcher.cpp:638
@@ -511,7 +511,7 @@ msgstr "
 
 #: gui/launcher.cpp:999
 #, fuzzy
-msgid "Do you want to load savegame?"
+msgid "Do you want to load saved game?"
 msgstr "²Ø åÞçÕâÕ ×ÐÒÐÝâÐÖØâØ Óàã?"
 
 #: gui/launcher.cpp:1048
@@ -915,7 +915,7 @@ msgid "You have to restart ScummVM before your changes will take effect."
 msgstr "²Ø ßÞÒØÝÝö ßÕàÕ×ÐßãáâØâØ ScummVM éÞÑ ×ÐáâÞáãÒÐâØ ×ÜöÝØ."
 
 #: gui/options.cpp:1379
-msgid "Select directory for savegames"
+msgid "Select directory for saved games"
 msgstr "²ØÑÕàöâì ßÐßÚã ÔÛï ×ÑÕàÕÖÕÝì"
 
 #: gui/options.cpp:1386
@@ -967,7 +967,7 @@ msgid "Delete"
 msgstr "²ØÔÐÛØâØ"
 
 #: gui/saveload-dialog.cpp:275
-msgid "Do you really want to delete this savegame?"
+msgid "Do you really want to delete this saved game?"
 msgstr "²Ø ÔöÙáÝÞ åÞçÕâÕ ÒØÔÐÛØâØ æÕ ×ÑÕàÕÖÕÝÝï?"
 
 #: gui/saveload-dialog.cpp:385 gui/saveload-dialog.cpp:875


Commit: cf8e28c40c68b1d74e6bba76848db7c39b2a00d8
    https://github.com/scummvm/scummvm/commit/cf8e28c40c68b1d74e6bba76848db7c39b2a00d8
Author: Ben Castricum (github at bencastricum.nl)
Date: 2014-08-22T07:11:03+02:00

Commit Message:
CLI: change "savegames" into "saved games", same as in GUI

Changed paths:
    base/commandLine.cpp



diff --git a/gui/saveload-dialog.cpp b/gui/saveload-dialog.cpp
index f6eee3a..339ec95 100644
--- a/gui/saveload-dialog.cpp
+++ b/gui/saveload-dialog.cpp
@@ -92,7 +92,7 @@ void SaveLoadChooserDialog::open() {
 	Dialog::open();
 
 	// So that quitting ScummVM will not cause the dialog result to say a
-	// savegame was selected.
+	// saved game was selected.
 	setResult(-1);
 }
 
@@ -272,7 +272,7 @@ void SaveLoadChooserSimple::handleCommand(CommandSender *sender, uint32 cmd, uin
 		break;
 	case kDelCmd:
 		if (selItem >= 0 && _delSupport) {
-			MessageDialog alert(_("Do you really want to delete this savegame?"),
+			MessageDialog alert(_("Do you really want to delete this saved game?"),
 								_("Delete"), _("Cancel"));
 			if (alert.runModal() == kMessageOK) {
 				_metaEngine->removeSaveState(_target.c_str(), _saveList[selItem].getSaveSlot());
@@ -488,7 +488,7 @@ void SaveLoadChooserSimple::updateSaveList() {
 			}
 		}
 
 		// Show "Untitled savestate" for empty/whitespace savegame descriptions
 		Common::String description = x->getDescription();
 		Common::String trimmedDescription = description;
 		trimmedDescription.trim();
@@ -488,7 +488,7 @@ void SaveLoadChooserSimple::updateSaveList() {
 		}
 
-		// Show "Untitled savestate" for empty/whitespace savegame descriptions
+		// Show "Untitled savestate" for empty/whitespace saved game descriptions
 		Common::String description = x->getDescription();
 		Common::String trimmedDescription = description;
diff --git a/base/commandLine.cpp b/base/commandLine.cpp
index d883323..285fd63 100644
--- a/base/commandLine.cpp
+++ b/base/commandLine.cpp
@@ -67,7 +67,7 @@ static const char HELP_STRING[] =
 	"  -h, --help               Display a brief help text and exit\n"
 	"  -z, --list-games         Display list of supported games and exit\n"
 	"  -t, --list-targets       Display list of configured targets and exit\n"
-	"  --list-saves=TARGET      Display a list of savegames for the game (TARGET) specified\n"
+	"  --list-saves=TARGET      Display a list of saved games for the game (TARGET) specified\n"
 #if defined(WIN32) && !defined(_WIN32_WCE) && !defined(__SYMBIAN32__)
 	"  --console                Enable the console window (default:enabled)\n"
 #endif
@@ -106,7 +106,7 @@ static const char HELP_STRING[] =
 	"  --platform=WORD          Specify platform of game (allowed values: 2gs, 3do,\n"
 	"                           acorn, amiga, atari, c64, fmtowns, nes, mac, pc, pc98,\n"
 	"                           pce, segacd, wii, windows)\n"
-	"  --savepath=PATH          Path to where savegames are stored\n"
+	"  --savepath=PATH          Path to where saved games are stored\n"
 	"  --extrapath=PATH         Extra path to additional game data\n"
 	"  --soundfont=FILE         Select the SoundFont for MIDI playback (only\n"
 	"                           supported by some MIDI drivers)\n"
@@ -401,7 +401,7 @@ Common::String parseCommandLine(Common::StringMap &settings, int argc, const cha
 
 			DO_LONG_OPTION("list-saves")
 				// FIXME: Need to document this.
 				// TODO: Make the argument optional. If no argument is given, list all savegames
 				// for all configured targets.
 				return "list-saves";
 			END_OPTION
@@ -529,9 +529,9 @@ Common::String parseCommandLine(Common::StringMap &settings, int argc, const cha
 			DO_LONG_OPTION("savepath")
 				Common::FSNode path(option);
 				if (!path.exists()) {
-					usage("Non-existent savegames path '%s'", option);
+					usage("Non-existent saved games path '%s'", option);
 				} else if (!path.isWritable()) {
-					usage("Non-writable savegames path '%s'", option);
+					usage("Non-writable saved games path '%s'", option);
 				}
 			END_OPTION
 
@@ -693,7 +693,7 @@ static Common::Error listSaves(const char *target) {
 		return Common::Error(Common::kEnginePluginNotSupportSaves,
 						Common::String::format("target '%s', gameid '%s", target, gameid.c_str()));
 	} else {
 		// Query the plugin for a list of savegames
 		SaveStateList saveList = (*plugin)->listSaves(target);
 
 		if (saveList.size() > 0) {
@@ -401,7 +401,7 @@ Common::String parseCommandLine(Common::StringMap &settings, int argc, const cha
 			DO_LONG_OPTION("list-saves")
 				// FIXME: Need to document this.
-				// TODO: Make the argument optional. If no argument is given, list all savegames
+				// TODO: Make the argument optional. If no argument is given, list all saved games
 				// for all configured targets.
 				return "list-saves";
@@ -693,7 +693,7 @@ static Common::Error listSaves(const char *target) {
 						Common::String::format("target '%s', gameid '%s", target, gameid.c_str()));
 	} else {
-		// Query the plugin for a list of savegames
+		// Query the plugin for a list of saved games
 		SaveStateList saveList = (*plugin)->listSaves(target);
 


Commit: 03b8800080bcf348c938ff3db0e7545798568973
    https://github.com/scummvm/scummvm/commit/03b8800080bcf348c938ff3db0e7545798568973
Author: Johannes Schickel (lordhoto at gmail.com)
Date: 2014-09-03T00:01:57+02:00

Commit Message:
Merge pull request #492 from BenCastricum/misc

GUI: replace "savegame" by "saved game".

Changed paths:
    base/commandLine.cpp
    gui/launcher.cpp
    gui/options.cpp
    gui/saveload-dialog.cpp
    po/be_BY.po
    po/ca_ES.po
    po/cs_CZ.po
    po/da_DA.po
    po/de_DE.po
    po/es_ES.po
    po/eu.po
    po/fi_FI.po
    po/fr_FR.po
    po/gl_ES.po
    po/hu_HU.po
    po/it_IT.po
    po/nb_NO.po
    po/nn_NO.po
    po/pl_PL.po
    po/pt_BR.po
    po/ru_RU.po
    po/se_SE.po
    po/uk_UA.po









More information about the Scummvm-git-logs mailing list